---------
Averaging
---------

Routines for averaging visibility data.


Numpy
~~~~~

.. currentmodule:: africanus.averaging

.. autosummary::
    time_and_channel

.. autofunction:: time_and_channel


Dask
~~~~

.. currentmodule:: africanus.averaging.dask

.. autosummary::
    time_and_channel

.. autofunction:: time_and_channel

